OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Nimi on liian pitkä",
    "The given web address is too long" : "Verkko-osoite on liian pitkä",
    "The given web address is not a valid URL" : "Annettu verkko-osoite ei ole kelvollinen URL",
    "The given legal notice address is too long" : "Annettu lainopillisen huomautuksen osoite on liian pitkä",
    "The given legal notice address is not a valid URL" : "Annettu lainopillisen huomautuksen osoite ei ole kelvollinen URL",
    "The given privacy policy address is too long" : "Annettu yksityiskäytännön osoite on liian pitkä",
    "The given privacy policy address is not a valid URL" : "Annettu yksityiskäytännön osoite ei ole kelvollinen URL",
    "The given slogan is too long" : "Slogani on liian pitkä",
    "The given color is invalid" : "Väri on virheellinen",
    "Saved" : "Tallennettu",
    "The file was uploaded" : "Tiedosto lähetettiin",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lähetetty tiedosto ylittää php.ini-tiedoston upload_max_filesize-tietueen arvon",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lähetettävän tiedoston enimmäiskoko ylittää HTML-lomakkeessa määritellyn MAX_FILE_SIZE-säännön",
    "The file was only partially uploaded" : "Tiedosto lähetettiin vain osittain",
    "No file was uploaded" : "Tiedostoa ei lähetetty",
    "Missing a temporary folder" : "Väliaikaiskansio puuttuu",
    "Could not write file to disk" : "Tiedostoa ei voitu kirjoittaa levylle",
    "A PHP extension stopped the file upload" : "PHP-laajennus pysäytti tiedoston lähettämisen",
    "No file uploaded" : "Ei tiedostoa lähetetty",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Käytät jo mukautettua teemaa. Teemoitussovelluksen asetukset saatetaan ohittaa.",
    "Theming" : "Teema",
    "Appearance and accessibility" : "Ulkoasu ja saavutettavuus",
    "PHP Imagick module" : "PHP:n Imagick-moduuli",
    "Dark theme with high contrast mode" : "Tumma teema korkean kontrastin tilalla",
    "Enable dark high contrast mode" : "Ota käyttöön tumma korkean kontrastin tila",
    "Similar to the high contrast mode, but with dark colours." : "Samankaltainen korkean kontrastin tilan kanssa, mutta tummien värien kera.",
    "Dark theme" : "Tumma teema",
    "Enable dark theme" : "Käytä tummaa teemaa",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Tumma teema, joka estää silmien rasittumista vähentämällä kirkkautta.",
    "System default theme" : "Järjestelmän oletusteema",
    "Enable the system default" : "Käytä järjestelmän oletusta",
    "Using the default system appearance." : "Käytetään järjestelmän oletusarvoista ulkoasua.",
    "Dyslexia font" : "Lukihäiriökirjasin",
    "Enable dyslexia font" : "Käytä lukihäiriökirjasinta",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic on vapaa kirjasin, joka on suunniteltu lieventämään lukihäiriön aiheuttamia lukuvirheitä.",
    "High contrast mode" : "Suuren kontrastin tila",
    "Enable high contrast mode" : "Käytä suuren kontrastin tilaa",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Suuren kontrasin tila helpottaa liikkumista. Visuaalista näyttävyyttä karsitaan hieman, jotta käyttöliittymä olisi jopa aiempaa selkeämpi.",
    "Light theme" : "Vaalea teema",
    "Enable the default light theme" : "Ota käyttöön oletusarvoinen vaalea teema",
    "The default light appearance." : "Oletusarvoinen vaalea ulkoasu.",
    "Legal notice" : "Lainopillinen huomautus",
    "Privacy policy" : "Yksityisyyskäytäntö",
    "Adjust the Nextcloud theme" : "Mukauta Nextcloudin teemaa",
    "Name" : "Nimi",
    "Web link" : "Verkkolinkki",
    "a safe home for all your data" : "turvallinen koti kaikille tiedostoillesi",
    "Slogan" : "Slogani",
    "Legal notice link" : "Lainopillisen huomautuksen linkki",
    "Privacy policy link" : "Yksityisyyskäytännön linkki",
    "Header logo" : "Otsakelogo",
    "Upload new header logo" : "Lähetä uusi otsakelogo",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Lähetä uusi favicon",
    "User settings" : "Käyttäjäasetukset",
    "Disable user theming" : "Poista käyttäjäteemoitus käytöstä",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Vaikka voit mukauttaa instanssia, käyttäjät voivat vaihtaa taustakuvaansa ja värejään. Jos haluat pakottaa mukautukset käyttäjille, ota tämä asetus käyttöön.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teeman avulla voit helposti kustomoida web-käyttöliittymän ja tuettujen sovelluksien ulkonäköä ja tuntumaa. Teema näkyy kaikille käyttäjille.",
    "Upload new logo" : "Lähetä uusi logo",
    "Logo" : "Logo",
    "Upload new background and login image" : "Lähetä uusi taustakuva ja kirjautumissivun kuva",
    "Background and login image" : "Tausta- ja kirjautumiskuva",
    "Advanced options" : "Lisävalinnat",
    "Appearance and accessibility settings" : "Ulkoasun ja saavutettavuuden asetukset",
    "Customization has been disabled by your administrator" : "Mukauttaminen on poistettu käytöstä ylläpitäjän toimesta",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Disable all keyboard shortcuts" : "Poista käytöstä kaikki pikanäppäimet",
    "Move up" : "Siirrä ylös",
    "Move down" : "Siirrä alas",
    "Select a background from your files" : "Valitse taustakuva tiedostoista",
    "Select background" : "Valitse tausta",
    "No background has been selected" : "Taustaa ei ole valittu",
    "Custom background" : "Mukautettu taustakuva",
    "Plain background" : "Yksinkertainen tausta",
    "Default background" : "Oletustausta",
    "Theme selection is enforced" : "Teemavalinta on pakotettu",
    "Navigation bar settings" : "Navigointipalkin asetukset",
    "Default app" : "Oletussovellus",
    "Use custom default app" : "Käytä mukautettua oletussovellusta",
    "Select a custom color" : "Valitse mukautettu väri",
    "Reset to default" : "Palauta oletukseksi",
    "Upload" : "Lähetä",
    "Remove background image" : "Poista taustakuva",
    "Color" : "Väri",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Saavutettavuus on erittäin tärkeää meille. Seuraamme verkkostandardeja ja varmistamme, että kaikki on käytettävissä ilman hiirtä sekä avustavien ohjelmistojen kuten ruudunlukijoiden avulla. Pyrimme olemaan yhteensopivia {guidelines}Web Content Accessibility Guidelines{linkend} -ohjeistuksen version 2.1 AA-tason kanssa, suuren kontrastin teemalla pyrimme jopa AAA-tasoon.",
    "Background" : "Tausta",
    "Set a custom background" : "Aseta mukautettu tausta",
    "Change color" : "Vaihda väriä",
    "No background" : "Ei taustakuvaa"
},
"nplurals=2; plural=(n != 1);");
